# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['SiteArgs', 'Site']

@pulumi.input_type
class SiteArgs:
    def __init__(__self__, *,
                 instance_id: pulumi.Input[builtins.str],
                 site_name: pulumi.Input[builtins.str],
                 access_type: Optional[pulumi.Input[builtins.str]] = None,
                 add_client_geolocation_header: Optional[pulumi.Input[builtins.str]] = None,
                 add_real_client_ip_header: Optional[pulumi.Input[builtins.str]] = None,
                 cache_architecture_mode: Optional[pulumi.Input[builtins.str]] = None,
                 coverage: Optional[pulumi.Input[builtins.str]] = None,
                 ipv6_enable: Optional[pulumi.Input[builtins.str]] = None,
                 resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 site_version: Optional[pulumi.Input[builtins.int]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None):
        """
        The set of arguments for constructing a Site resource.
        :param pulumi.Input[builtins.str] instance_id: The ID of the associated package instance.
        :param pulumi.Input[builtins.str] site_name: The website name.
        :param pulumi.Input[builtins.str] access_type: The DNS setup. Valid values:
               - `NS`
               - `CNAME`
        :param pulumi.Input[builtins.str] add_client_geolocation_header: Add visitor geolocation header. Value range:
        :param pulumi.Input[builtins.str] add_real_client_ip_header: Add the "ali-real-client-ip" header containing the real client IP. Value range:
        :param pulumi.Input[builtins.str] cache_architecture_mode: Multi-level cache architecture mode. Possible values:
        :param pulumi.Input[builtins.str] coverage: The service location. Valid values:
        :param pulumi.Input[builtins.str] ipv6_enable: Specifies whether to enable IPv6. Valid values:
        :param pulumi.Input[builtins.str] resource_group_id: The ID of the resource group
        :param pulumi.Input[builtins.int] site_version: The version number of the site. For sites with version management enabled, you can use this parameter to specify the site version for which the configuration will take effect, defaulting to version 0.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: Resource tags
        """
        pulumi.set(__self__, "instance_id", instance_id)
        pulumi.set(__self__, "site_name", site_name)
        if access_type is not None:
            pulumi.set(__self__, "access_type", access_type)
        if add_client_geolocation_header is not None:
            pulumi.set(__self__, "add_client_geolocation_header", add_client_geolocation_header)
        if add_real_client_ip_header is not None:
            pulumi.set(__self__, "add_real_client_ip_header", add_real_client_ip_header)
        if cache_architecture_mode is not None:
            pulumi.set(__self__, "cache_architecture_mode", cache_architecture_mode)
        if coverage is not None:
            pulumi.set(__self__, "coverage", coverage)
        if ipv6_enable is not None:
            pulumi.set(__self__, "ipv6_enable", ipv6_enable)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if site_version is not None:
            pulumi.set(__self__, "site_version", site_version)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Input[builtins.str]:
        """
        The ID of the associated package instance.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="siteName")
    def site_name(self) -> pulumi.Input[builtins.str]:
        """
        The website name.
        """
        return pulumi.get(self, "site_name")

    @site_name.setter
    def site_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "site_name", value)

    @property
    @pulumi.getter(name="accessType")
    def access_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The DNS setup. Valid values:
        - `NS`
        - `CNAME`
        """
        return pulumi.get(self, "access_type")

    @access_type.setter
    def access_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "access_type", value)

    @property
    @pulumi.getter(name="addClientGeolocationHeader")
    def add_client_geolocation_header(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Add visitor geolocation header. Value range:
        """
        return pulumi.get(self, "add_client_geolocation_header")

    @add_client_geolocation_header.setter
    def add_client_geolocation_header(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "add_client_geolocation_header", value)

    @property
    @pulumi.getter(name="addRealClientIpHeader")
    def add_real_client_ip_header(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Add the "ali-real-client-ip" header containing the real client IP. Value range:
        """
        return pulumi.get(self, "add_real_client_ip_header")

    @add_real_client_ip_header.setter
    def add_real_client_ip_header(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "add_real_client_ip_header", value)

    @property
    @pulumi.getter(name="cacheArchitectureMode")
    def cache_architecture_mode(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Multi-level cache architecture mode. Possible values:
        """
        return pulumi.get(self, "cache_architecture_mode")

    @cache_architecture_mode.setter
    def cache_architecture_mode(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cache_architecture_mode", value)

    @property
    @pulumi.getter
    def coverage(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The service location. Valid values:
        """
        return pulumi.get(self, "coverage")

    @coverage.setter
    def coverage(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "coverage", value)

    @property
    @pulumi.getter(name="ipv6Enable")
    def ipv6_enable(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Specifies whether to enable IPv6. Valid values:
        """
        return pulumi.get(self, "ipv6_enable")

    @ipv6_enable.setter
    def ipv6_enable(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ipv6_enable", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the resource group
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter(name="siteVersion")
    def site_version(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The version number of the site. For sites with version management enabled, you can use this parameter to specify the site version for which the configuration will take effect, defaulting to version 0.
        """
        return pulumi.get(self, "site_version")

    @site_version.setter
    def site_version(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "site_version", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        Resource tags
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _SiteState:
    def __init__(__self__, *,
                 access_type: Optional[pulumi.Input[builtins.str]] = None,
                 add_client_geolocation_header: Optional[pulumi.Input[builtins.str]] = None,
                 add_real_client_ip_header: Optional[pulumi.Input[builtins.str]] = None,
                 cache_architecture_mode: Optional[pulumi.Input[builtins.str]] = None,
                 coverage: Optional[pulumi.Input[builtins.str]] = None,
                 create_time: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 ipv6_enable: Optional[pulumi.Input[builtins.str]] = None,
                 resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 site_name: Optional[pulumi.Input[builtins.str]] = None,
                 site_version: Optional[pulumi.Input[builtins.int]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering Site resources.
        :param pulumi.Input[builtins.str] access_type: The DNS setup. Valid values:
               - `NS`
               - `CNAME`
        :param pulumi.Input[builtins.str] add_client_geolocation_header: Add visitor geolocation header. Value range:
        :param pulumi.Input[builtins.str] add_real_client_ip_header: Add the "ali-real-client-ip" header containing the real client IP. Value range:
        :param pulumi.Input[builtins.str] cache_architecture_mode: Multi-level cache architecture mode. Possible values:
        :param pulumi.Input[builtins.str] coverage: The service location. Valid values:
        :param pulumi.Input[builtins.str] create_time: The time when the website was added. The time follows the ISO 8601 standard in the yyyy-MM-ddTHH:mm:ssZ format. The time is displayed in UTC.
        :param pulumi.Input[builtins.str] instance_id: The ID of the associated package instance.
        :param pulumi.Input[builtins.str] ipv6_enable: Specifies whether to enable IPv6. Valid values:
        :param pulumi.Input[builtins.str] resource_group_id: The ID of the resource group
        :param pulumi.Input[builtins.str] site_name: The website name.
        :param pulumi.Input[builtins.int] site_version: The version number of the site. For sites with version management enabled, you can use this parameter to specify the site version for which the configuration will take effect, defaulting to version 0.
        :param pulumi.Input[builtins.str] status: The status of the resource
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: Resource tags
        """
        if access_type is not None:
            pulumi.set(__self__, "access_type", access_type)
        if add_client_geolocation_header is not None:
            pulumi.set(__self__, "add_client_geolocation_header", add_client_geolocation_header)
        if add_real_client_ip_header is not None:
            pulumi.set(__self__, "add_real_client_ip_header", add_real_client_ip_header)
        if cache_architecture_mode is not None:
            pulumi.set(__self__, "cache_architecture_mode", cache_architecture_mode)
        if coverage is not None:
            pulumi.set(__self__, "coverage", coverage)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if ipv6_enable is not None:
            pulumi.set(__self__, "ipv6_enable", ipv6_enable)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if site_name is not None:
            pulumi.set(__self__, "site_name", site_name)
        if site_version is not None:
            pulumi.set(__self__, "site_version", site_version)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="accessType")
    def access_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The DNS setup. Valid values:
        - `NS`
        - `CNAME`
        """
        return pulumi.get(self, "access_type")

    @access_type.setter
    def access_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "access_type", value)

    @property
    @pulumi.getter(name="addClientGeolocationHeader")
    def add_client_geolocation_header(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Add visitor geolocation header. Value range:
        """
        return pulumi.get(self, "add_client_geolocation_header")

    @add_client_geolocation_header.setter
    def add_client_geolocation_header(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "add_client_geolocation_header", value)

    @property
    @pulumi.getter(name="addRealClientIpHeader")
    def add_real_client_ip_header(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Add the "ali-real-client-ip" header containing the real client IP. Value range:
        """
        return pulumi.get(self, "add_real_client_ip_header")

    @add_real_client_ip_header.setter
    def add_real_client_ip_header(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "add_real_client_ip_header", value)

    @property
    @pulumi.getter(name="cacheArchitectureMode")
    def cache_architecture_mode(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Multi-level cache architecture mode. Possible values:
        """
        return pulumi.get(self, "cache_architecture_mode")

    @cache_architecture_mode.setter
    def cache_architecture_mode(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cache_architecture_mode", value)

    @property
    @pulumi.getter
    def coverage(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The service location. Valid values:
        """
        return pulumi.get(self, "coverage")

    @coverage.setter
    def coverage(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "coverage", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The time when the website was added. The time follows the ISO 8601 standard in the yyyy-MM-ddTHH:mm:ssZ format. The time is displayed in UTC.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the associated package instance.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="ipv6Enable")
    def ipv6_enable(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Specifies whether to enable IPv6. Valid values:
        """
        return pulumi.get(self, "ipv6_enable")

    @ipv6_enable.setter
    def ipv6_enable(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ipv6_enable", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the resource group
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter(name="siteName")
    def site_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The website name.
        """
        return pulumi.get(self, "site_name")

    @site_name.setter
    def site_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "site_name", value)

    @property
    @pulumi.getter(name="siteVersion")
    def site_version(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The version number of the site. For sites with version management enabled, you can use this parameter to specify the site version for which the configuration will take effect, defaulting to version 0.
        """
        return pulumi.get(self, "site_version")

    @site_version.setter
    def site_version(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "site_version", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The status of the resource
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        Resource tags
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.type_token("alicloud:esa/site:Site")
class Site(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_type: Optional[pulumi.Input[builtins.str]] = None,
                 add_client_geolocation_header: Optional[pulumi.Input[builtins.str]] = None,
                 add_real_client_ip_header: Optional[pulumi.Input[builtins.str]] = None,
                 cache_architecture_mode: Optional[pulumi.Input[builtins.str]] = None,
                 coverage: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 ipv6_enable: Optional[pulumi.Input[builtins.str]] = None,
                 resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 site_name: Optional[pulumi.Input[builtins.str]] = None,
                 site_version: Optional[pulumi.Input[builtins.int]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        """
        Provides a ESA Site resource.

        For information about ESA Site and how to use it, see [What is Site](https://www.alibabacloud.com/help/en/edge-security-acceleration/esa/user-guide/site-management).

        > **NOTE:** Available since v1.234.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.resourcemanager.get_resource_groups()
        default_i_eo_df_u = alicloud.esa.RatePlanInstance("defaultIEoDfU",
            type="NS",
            auto_renew=True,
            period=1,
            payment_type="Subscription",
            coverage="overseas",
            auto_pay=True,
            plan_name="basic")
        default_integer = random.index.Integer("default",
            min=10000,
            max=99999)
        default_site = alicloud.esa.Site("default",
            site_name=f"bcd{default_integer['result']}.com",
            coverage="overseas",
            access_type="NS",
            instance_id=default_i_eo_df_u.id,
            resource_group_id=default.ids[0])
        ```

        ## Import

        ESA Site can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:esa/site:Site example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] access_type: The DNS setup. Valid values:
               - `NS`
               - `CNAME`
        :param pulumi.Input[builtins.str] add_client_geolocation_header: Add visitor geolocation header. Value range:
        :param pulumi.Input[builtins.str] add_real_client_ip_header: Add the "ali-real-client-ip" header containing the real client IP. Value range:
        :param pulumi.Input[builtins.str] cache_architecture_mode: Multi-level cache architecture mode. Possible values:
        :param pulumi.Input[builtins.str] coverage: The service location. Valid values:
        :param pulumi.Input[builtins.str] instance_id: The ID of the associated package instance.
        :param pulumi.Input[builtins.str] ipv6_enable: Specifies whether to enable IPv6. Valid values:
        :param pulumi.Input[builtins.str] resource_group_id: The ID of the resource group
        :param pulumi.Input[builtins.str] site_name: The website name.
        :param pulumi.Input[builtins.int] site_version: The version number of the site. For sites with version management enabled, you can use this parameter to specify the site version for which the configuration will take effect, defaulting to version 0.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: Resource tags
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SiteArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a ESA Site resource.

        For information about ESA Site and how to use it, see [What is Site](https://www.alibabacloud.com/help/en/edge-security-acceleration/esa/user-guide/site-management).

        > **NOTE:** Available since v1.234.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.resourcemanager.get_resource_groups()
        default_i_eo_df_u = alicloud.esa.RatePlanInstance("defaultIEoDfU",
            type="NS",
            auto_renew=True,
            period=1,
            payment_type="Subscription",
            coverage="overseas",
            auto_pay=True,
            plan_name="basic")
        default_integer = random.index.Integer("default",
            min=10000,
            max=99999)
        default_site = alicloud.esa.Site("default",
            site_name=f"bcd{default_integer['result']}.com",
            coverage="overseas",
            access_type="NS",
            instance_id=default_i_eo_df_u.id,
            resource_group_id=default.ids[0])
        ```

        ## Import

        ESA Site can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:esa/site:Site example <id>
        ```

        :param str resource_name: The name of the resource.
        :param SiteArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SiteArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_type: Optional[pulumi.Input[builtins.str]] = None,
                 add_client_geolocation_header: Optional[pulumi.Input[builtins.str]] = None,
                 add_real_client_ip_header: Optional[pulumi.Input[builtins.str]] = None,
                 cache_architecture_mode: Optional[pulumi.Input[builtins.str]] = None,
                 coverage: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 ipv6_enable: Optional[pulumi.Input[builtins.str]] = None,
                 resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 site_name: Optional[pulumi.Input[builtins.str]] = None,
                 site_version: Optional[pulumi.Input[builtins.int]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SiteArgs.__new__(SiteArgs)

            __props__.__dict__["access_type"] = access_type
            __props__.__dict__["add_client_geolocation_header"] = add_client_geolocation_header
            __props__.__dict__["add_real_client_ip_header"] = add_real_client_ip_header
            __props__.__dict__["cache_architecture_mode"] = cache_architecture_mode
            __props__.__dict__["coverage"] = coverage
            if instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'instance_id'")
            __props__.__dict__["instance_id"] = instance_id
            __props__.__dict__["ipv6_enable"] = ipv6_enable
            __props__.__dict__["resource_group_id"] = resource_group_id
            if site_name is None and not opts.urn:
                raise TypeError("Missing required property 'site_name'")
            __props__.__dict__["site_name"] = site_name
            __props__.__dict__["site_version"] = site_version
            __props__.__dict__["tags"] = tags
            __props__.__dict__["create_time"] = None
            __props__.__dict__["status"] = None
        super(Site, __self__).__init__(
            'alicloud:esa/site:Site',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            access_type: Optional[pulumi.Input[builtins.str]] = None,
            add_client_geolocation_header: Optional[pulumi.Input[builtins.str]] = None,
            add_real_client_ip_header: Optional[pulumi.Input[builtins.str]] = None,
            cache_architecture_mode: Optional[pulumi.Input[builtins.str]] = None,
            coverage: Optional[pulumi.Input[builtins.str]] = None,
            create_time: Optional[pulumi.Input[builtins.str]] = None,
            instance_id: Optional[pulumi.Input[builtins.str]] = None,
            ipv6_enable: Optional[pulumi.Input[builtins.str]] = None,
            resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
            site_name: Optional[pulumi.Input[builtins.str]] = None,
            site_version: Optional[pulumi.Input[builtins.int]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None) -> 'Site':
        """
        Get an existing Site resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] access_type: The DNS setup. Valid values:
               - `NS`
               - `CNAME`
        :param pulumi.Input[builtins.str] add_client_geolocation_header: Add visitor geolocation header. Value range:
        :param pulumi.Input[builtins.str] add_real_client_ip_header: Add the "ali-real-client-ip" header containing the real client IP. Value range:
        :param pulumi.Input[builtins.str] cache_architecture_mode: Multi-level cache architecture mode. Possible values:
        :param pulumi.Input[builtins.str] coverage: The service location. Valid values:
        :param pulumi.Input[builtins.str] create_time: The time when the website was added. The time follows the ISO 8601 standard in the yyyy-MM-ddTHH:mm:ssZ format. The time is displayed in UTC.
        :param pulumi.Input[builtins.str] instance_id: The ID of the associated package instance.
        :param pulumi.Input[builtins.str] ipv6_enable: Specifies whether to enable IPv6. Valid values:
        :param pulumi.Input[builtins.str] resource_group_id: The ID of the resource group
        :param pulumi.Input[builtins.str] site_name: The website name.
        :param pulumi.Input[builtins.int] site_version: The version number of the site. For sites with version management enabled, you can use this parameter to specify the site version for which the configuration will take effect, defaulting to version 0.
        :param pulumi.Input[builtins.str] status: The status of the resource
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: Resource tags
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SiteState.__new__(_SiteState)

        __props__.__dict__["access_type"] = access_type
        __props__.__dict__["add_client_geolocation_header"] = add_client_geolocation_header
        __props__.__dict__["add_real_client_ip_header"] = add_real_client_ip_header
        __props__.__dict__["cache_architecture_mode"] = cache_architecture_mode
        __props__.__dict__["coverage"] = coverage
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["ipv6_enable"] = ipv6_enable
        __props__.__dict__["resource_group_id"] = resource_group_id
        __props__.__dict__["site_name"] = site_name
        __props__.__dict__["site_version"] = site_version
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        return Site(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accessType")
    def access_type(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The DNS setup. Valid values:
        - `NS`
        - `CNAME`
        """
        return pulumi.get(self, "access_type")

    @property
    @pulumi.getter(name="addClientGeolocationHeader")
    def add_client_geolocation_header(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Add visitor geolocation header. Value range:
        """
        return pulumi.get(self, "add_client_geolocation_header")

    @property
    @pulumi.getter(name="addRealClientIpHeader")
    def add_real_client_ip_header(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Add the "ali-real-client-ip" header containing the real client IP. Value range:
        """
        return pulumi.get(self, "add_real_client_ip_header")

    @property
    @pulumi.getter(name="cacheArchitectureMode")
    def cache_architecture_mode(self) -> pulumi.Output[builtins.str]:
        """
        Multi-level cache architecture mode. Possible values:
        """
        return pulumi.get(self, "cache_architecture_mode")

    @property
    @pulumi.getter
    def coverage(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The service location. Valid values:
        """
        return pulumi.get(self, "coverage")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[builtins.str]:
        """
        The time when the website was added. The time follows the ISO 8601 standard in the yyyy-MM-ddTHH:mm:ssZ format. The time is displayed in UTC.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the associated package instance.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="ipv6Enable")
    def ipv6_enable(self) -> pulumi.Output[builtins.str]:
        """
        Specifies whether to enable IPv6. Valid values:
        """
        return pulumi.get(self, "ipv6_enable")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the resource group
        """
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter(name="siteName")
    def site_name(self) -> pulumi.Output[builtins.str]:
        """
        The website name.
        """
        return pulumi.get(self, "site_name")

    @property
    @pulumi.getter(name="siteVersion")
    def site_version(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        The version number of the site. For sites with version management enabled, you can use this parameter to specify the site version for which the configuration will take effect, defaulting to version 0.
        """
        return pulumi.get(self, "site_version")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        The status of the resource
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, builtins.str]]]:
        """
        Resource tags
        """
        return pulumi.get(self, "tags")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ScheduledPreloadExecutionArgs', 'ScheduledPreloadExecution']

@pulumi.input_type
class ScheduledPreloadExecutionArgs:
    def __init__(__self__, *,
                 interval: pulumi.Input[builtins.int],
                 scheduled_preload_job_id: pulumi.Input[builtins.str],
                 slice_len: pulumi.Input[builtins.int],
                 end_time: Optional[pulumi.Input[builtins.str]] = None,
                 start_time: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a ScheduledPreloadExecution resource.
        :param pulumi.Input[builtins.int] interval: The time interval between each batch execution. Unit: seconds.
        :param pulumi.Input[builtins.str] scheduled_preload_job_id: The ID of the prefetch task.
        :param pulumi.Input[builtins.int] slice_len: The number of URLs prefetched in each batch.
        :param pulumi.Input[builtins.str] end_time: The end time of the prefetch plan.
        :param pulumi.Input[builtins.str] start_time: The start time of the prefetch plan.
        """
        pulumi.set(__self__, "interval", interval)
        pulumi.set(__self__, "scheduled_preload_job_id", scheduled_preload_job_id)
        pulumi.set(__self__, "slice_len", slice_len)
        if end_time is not None:
            pulumi.set(__self__, "end_time", end_time)
        if start_time is not None:
            pulumi.set(__self__, "start_time", start_time)

    @property
    @pulumi.getter
    def interval(self) -> pulumi.Input[builtins.int]:
        """
        The time interval between each batch execution. Unit: seconds.
        """
        return pulumi.get(self, "interval")

    @interval.setter
    def interval(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "interval", value)

    @property
    @pulumi.getter(name="scheduledPreloadJobId")
    def scheduled_preload_job_id(self) -> pulumi.Input[builtins.str]:
        """
        The ID of the prefetch task.
        """
        return pulumi.get(self, "scheduled_preload_job_id")

    @scheduled_preload_job_id.setter
    def scheduled_preload_job_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "scheduled_preload_job_id", value)

    @property
    @pulumi.getter(name="sliceLen")
    def slice_len(self) -> pulumi.Input[builtins.int]:
        """
        The number of URLs prefetched in each batch.
        """
        return pulumi.get(self, "slice_len")

    @slice_len.setter
    def slice_len(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "slice_len", value)

    @property
    @pulumi.getter(name="endTime")
    def end_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The end time of the prefetch plan.
        """
        return pulumi.get(self, "end_time")

    @end_time.setter
    def end_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "end_time", value)

    @property
    @pulumi.getter(name="startTime")
    def start_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The start time of the prefetch plan.
        """
        return pulumi.get(self, "start_time")

    @start_time.setter
    def start_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "start_time", value)


@pulumi.input_type
class _ScheduledPreloadExecutionState:
    def __init__(__self__, *,
                 end_time: Optional[pulumi.Input[builtins.str]] = None,
                 interval: Optional[pulumi.Input[builtins.int]] = None,
                 scheduled_preload_execution_id: Optional[pulumi.Input[builtins.str]] = None,
                 scheduled_preload_job_id: Optional[pulumi.Input[builtins.str]] = None,
                 slice_len: Optional[pulumi.Input[builtins.int]] = None,
                 start_time: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering ScheduledPreloadExecution resources.
        :param pulumi.Input[builtins.str] end_time: The end time of the prefetch plan.
        :param pulumi.Input[builtins.int] interval: The time interval between each batch execution. Unit: seconds.
        :param pulumi.Input[builtins.str] scheduled_preload_execution_id: The ID of the prefetch plan.
        :param pulumi.Input[builtins.str] scheduled_preload_job_id: The ID of the prefetch task.
        :param pulumi.Input[builtins.int] slice_len: The number of URLs prefetched in each batch.
        :param pulumi.Input[builtins.str] start_time: The start time of the prefetch plan.
        :param pulumi.Input[builtins.str] status: The status of the prefetch plan, including the following statuses.
        """
        if end_time is not None:
            pulumi.set(__self__, "end_time", end_time)
        if interval is not None:
            pulumi.set(__self__, "interval", interval)
        if scheduled_preload_execution_id is not None:
            pulumi.set(__self__, "scheduled_preload_execution_id", scheduled_preload_execution_id)
        if scheduled_preload_job_id is not None:
            pulumi.set(__self__, "scheduled_preload_job_id", scheduled_preload_job_id)
        if slice_len is not None:
            pulumi.set(__self__, "slice_len", slice_len)
        if start_time is not None:
            pulumi.set(__self__, "start_time", start_time)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="endTime")
    def end_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The end time of the prefetch plan.
        """
        return pulumi.get(self, "end_time")

    @end_time.setter
    def end_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "end_time", value)

    @property
    @pulumi.getter
    def interval(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The time interval between each batch execution. Unit: seconds.
        """
        return pulumi.get(self, "interval")

    @interval.setter
    def interval(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "interval", value)

    @property
    @pulumi.getter(name="scheduledPreloadExecutionId")
    def scheduled_preload_execution_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the prefetch plan.
        """
        return pulumi.get(self, "scheduled_preload_execution_id")

    @scheduled_preload_execution_id.setter
    def scheduled_preload_execution_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "scheduled_preload_execution_id", value)

    @property
    @pulumi.getter(name="scheduledPreloadJobId")
    def scheduled_preload_job_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the prefetch task.
        """
        return pulumi.get(self, "scheduled_preload_job_id")

    @scheduled_preload_job_id.setter
    def scheduled_preload_job_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "scheduled_preload_job_id", value)

    @property
    @pulumi.getter(name="sliceLen")
    def slice_len(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The number of URLs prefetched in each batch.
        """
        return pulumi.get(self, "slice_len")

    @slice_len.setter
    def slice_len(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "slice_len", value)

    @property
    @pulumi.getter(name="startTime")
    def start_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The start time of the prefetch plan.
        """
        return pulumi.get(self, "start_time")

    @start_time.setter
    def start_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "start_time", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The status of the prefetch plan, including the following statuses.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.type_token("alicloud:esa/scheduledPreloadExecution:ScheduledPreloadExecution")
class ScheduledPreloadExecution(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 end_time: Optional[pulumi.Input[builtins.str]] = None,
                 interval: Optional[pulumi.Input[builtins.int]] = None,
                 scheduled_preload_job_id: Optional[pulumi.Input[builtins.str]] = None,
                 slice_len: Optional[pulumi.Input[builtins.int]] = None,
                 start_time: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a ESA Scheduled Preload Execution resource.

        For information about ESA Scheduled Preload Execution and how to use it, see [What is Scheduled Preload Execution](https://next.api.alibabacloud.com/document/ESA/2024-09-10/CreateScheduledPreloadExecutions).

        > **NOTE:** Available since v1.248.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.esa.get_sites(plan_subscribe_type="enterpriseplan")
        default_site = alicloud.esa.Site("default",
            site_name="terraform.cn",
            instance_id=default.sites[0].instance_id,
            coverage="overseas",
            access_type="NS")
        default_scheduled_preload_job = alicloud.esa.ScheduledPreloadJob("default",
            insert_way="textBox",
            site_id=default_site.id,
            scheduled_preload_job_name="example_scheduledpreloadexecution_job",
            url_list="http://example.gositecdn.cn/example/example.txt")
        default_scheduled_preload_execution = alicloud.esa.ScheduledPreloadExecution("default",
            slice_len=5,
            end_time="2024-06-04T10:02:09.000+08:00",
            start_time="2024-06-04T00:00:00.000+08:00",
            scheduled_preload_job_id=default_scheduled_preload_job.scheduled_preload_job_id,
            interval=30)
        ```

        ## Import

        ESA Scheduled Preload Execution can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:esa/scheduledPreloadExecution:ScheduledPreloadExecution example <scheduled_preload_job_id>:<scheduled_preload_execution_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] end_time: The end time of the prefetch plan.
        :param pulumi.Input[builtins.int] interval: The time interval between each batch execution. Unit: seconds.
        :param pulumi.Input[builtins.str] scheduled_preload_job_id: The ID of the prefetch task.
        :param pulumi.Input[builtins.int] slice_len: The number of URLs prefetched in each batch.
        :param pulumi.Input[builtins.str] start_time: The start time of the prefetch plan.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ScheduledPreloadExecutionArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a ESA Scheduled Preload Execution resource.

        For information about ESA Scheduled Preload Execution and how to use it, see [What is Scheduled Preload Execution](https://next.api.alibabacloud.com/document/ESA/2024-09-10/CreateScheduledPreloadExecutions).

        > **NOTE:** Available since v1.248.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.esa.get_sites(plan_subscribe_type="enterpriseplan")
        default_site = alicloud.esa.Site("default",
            site_name="terraform.cn",
            instance_id=default.sites[0].instance_id,
            coverage="overseas",
            access_type="NS")
        default_scheduled_preload_job = alicloud.esa.ScheduledPreloadJob("default",
            insert_way="textBox",
            site_id=default_site.id,
            scheduled_preload_job_name="example_scheduledpreloadexecution_job",
            url_list="http://example.gositecdn.cn/example/example.txt")
        default_scheduled_preload_execution = alicloud.esa.ScheduledPreloadExecution("default",
            slice_len=5,
            end_time="2024-06-04T10:02:09.000+08:00",
            start_time="2024-06-04T00:00:00.000+08:00",
            scheduled_preload_job_id=default_scheduled_preload_job.scheduled_preload_job_id,
            interval=30)
        ```

        ## Import

        ESA Scheduled Preload Execution can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:esa/scheduledPreloadExecution:ScheduledPreloadExecution example <scheduled_preload_job_id>:<scheduled_preload_execution_id>
        ```

        :param str resource_name: The name of the resource.
        :param ScheduledPreloadExecutionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ScheduledPreloadExecutionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 end_time: Optional[pulumi.Input[builtins.str]] = None,
                 interval: Optional[pulumi.Input[builtins.int]] = None,
                 scheduled_preload_job_id: Optional[pulumi.Input[builtins.str]] = None,
                 slice_len: Optional[pulumi.Input[builtins.int]] = None,
                 start_time: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ScheduledPreloadExecutionArgs.__new__(ScheduledPreloadExecutionArgs)

            __props__.__dict__["end_time"] = end_time
            if interval is None and not opts.urn:
                raise TypeError("Missing required property 'interval'")
            __props__.__dict__["interval"] = interval
            if scheduled_preload_job_id is None and not opts.urn:
                raise TypeError("Missing required property 'scheduled_preload_job_id'")
            __props__.__dict__["scheduled_preload_job_id"] = scheduled_preload_job_id
            if slice_len is None and not opts.urn:
                raise TypeError("Missing required property 'slice_len'")
            __props__.__dict__["slice_len"] = slice_len
            __props__.__dict__["start_time"] = start_time
            __props__.__dict__["scheduled_preload_execution_id"] = None
            __props__.__dict__["status"] = None
        super(ScheduledPreloadExecution, __self__).__init__(
            'alicloud:esa/scheduledPreloadExecution:ScheduledPreloadExecution',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            end_time: Optional[pulumi.Input[builtins.str]] = None,
            interval: Optional[pulumi.Input[builtins.int]] = None,
            scheduled_preload_execution_id: Optional[pulumi.Input[builtins.str]] = None,
            scheduled_preload_job_id: Optional[pulumi.Input[builtins.str]] = None,
            slice_len: Optional[pulumi.Input[builtins.int]] = None,
            start_time: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None) -> 'ScheduledPreloadExecution':
        """
        Get an existing ScheduledPreloadExecution resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] end_time: The end time of the prefetch plan.
        :param pulumi.Input[builtins.int] interval: The time interval between each batch execution. Unit: seconds.
        :param pulumi.Input[builtins.str] scheduled_preload_execution_id: The ID of the prefetch plan.
        :param pulumi.Input[builtins.str] scheduled_preload_job_id: The ID of the prefetch task.
        :param pulumi.Input[builtins.int] slice_len: The number of URLs prefetched in each batch.
        :param pulumi.Input[builtins.str] start_time: The start time of the prefetch plan.
        :param pulumi.Input[builtins.str] status: The status of the prefetch plan, including the following statuses.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ScheduledPreloadExecutionState.__new__(_ScheduledPreloadExecutionState)

        __props__.__dict__["end_time"] = end_time
        __props__.__dict__["interval"] = interval
        __props__.__dict__["scheduled_preload_execution_id"] = scheduled_preload_execution_id
        __props__.__dict__["scheduled_preload_job_id"] = scheduled_preload_job_id
        __props__.__dict__["slice_len"] = slice_len
        __props__.__dict__["start_time"] = start_time
        __props__.__dict__["status"] = status
        return ScheduledPreloadExecution(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="endTime")
    def end_time(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The end time of the prefetch plan.
        """
        return pulumi.get(self, "end_time")

    @property
    @pulumi.getter
    def interval(self) -> pulumi.Output[builtins.int]:
        """
        The time interval between each batch execution. Unit: seconds.
        """
        return pulumi.get(self, "interval")

    @property
    @pulumi.getter(name="scheduledPreloadExecutionId")
    def scheduled_preload_execution_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the prefetch plan.
        """
        return pulumi.get(self, "scheduled_preload_execution_id")

    @property
    @pulumi.getter(name="scheduledPreloadJobId")
    def scheduled_preload_job_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the prefetch task.
        """
        return pulumi.get(self, "scheduled_preload_job_id")

    @property
    @pulumi.getter(name="sliceLen")
    def slice_len(self) -> pulumi.Output[builtins.int]:
        """
        The number of URLs prefetched in each batch.
        """
        return pulumi.get(self, "slice_len")

    @property
    @pulumi.getter(name="startTime")
    def start_time(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The start time of the prefetch plan.
        """
        return pulumi.get(self, "start_time")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        The status of the prefetch plan, including the following statuses.
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['GroupArgs', 'Group']

@pulumi.input_type
class GroupArgs:
    def __init__(__self__, *,
                 image_id: pulumi.Input[builtins.str],
                 instance_group_spec: pulumi.Input[builtins.str],
                 amount: Optional[pulumi.Input[builtins.int]] = None,
                 auto_pay: Optional[pulumi.Input[builtins.bool]] = None,
                 auto_renew: Optional[pulumi.Input[builtins.bool]] = None,
                 charge_type: Optional[pulumi.Input[builtins.str]] = None,
                 gpu_acceleration: Optional[pulumi.Input[builtins.bool]] = None,
                 instance_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 number_of_instances: Optional[pulumi.Input[builtins.int]] = None,
                 office_site_id: Optional[pulumi.Input[builtins.str]] = None,
                 period: Optional[pulumi.Input[builtins.int]] = None,
                 period_unit: Optional[pulumi.Input[builtins.str]] = None,
                 policy_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 vswitch_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Group resource.
        :param pulumi.Input[builtins.str] image_id: The image ID.
        :param pulumi.Input[builtins.str] instance_group_spec: Instance group specifications.
        :param pulumi.Input[builtins.int] amount: The number of instance groups. The default value is 1 and the maximum value is 100.
        :param pulumi.Input[builtins.bool] auto_pay: Whether to pay automatically. The default is false.
        :param pulumi.Input[builtins.bool] auto_renew: Whether to enable automatic renewal. The default is false.
        :param pulumi.Input[builtins.str] charge_type: The billing type.
        :param pulumi.Input[builtins.bool] gpu_acceleration: Whether to enable GPU acceleration. The default value is false.
               - true: On.
               - false: closed.
        :param pulumi.Input[builtins.str] instance_group_name: The instance group name
               
               > **NOTE:** >
               
               > **NOTE:** - The instance group name must be no more than 30 characters in length. Start with an uppercase/lowercase letter or Chinese. It cannot start with http:// or https://. Only Chinese, English, numbers, half-width colons (:), underscores (_), periods (.), or hyphens (-) are supported.
        :param pulumi.Input[builtins.int] number_of_instances: The number of instances in the instance group. The maximum value is 100.
        :param pulumi.Input[builtins.str] office_site_id: The network ID.
               - Create a shared network instance: Network ID is optional. Enter the network ID whose type is **Shared Network** on the [cloud mobile phone console> Network](https://wya.wuying.aliyun.com/network) page. If the console does not have a shared network, you can fill it in. A shared network is automatically created when the instance group is created.
               - Create a VPC instance: the network ID is required. Enter the network ID of `VPC` on the [cloud mobile phone console> Network](https://wya.wuying.aliyun.com/network) page. If the console does not have a VPC network, you need to create a network first.
        :param pulumi.Input[builtins.int] period: The duration of the resource purchase. The unit is specified by PeriodUnit.
        :param pulumi.Input[builtins.str] period_unit: The unit of time for purchasing resources.
        :param pulumi.Input[builtins.str] policy_group_id: The policy ID. You can query the list of policies by calling ListPolicyGroups.
        :param pulumi.Input[builtins.str] vswitch_id: The vSwitch ID.
        """
        pulumi.set(__self__, "image_id", image_id)
        pulumi.set(__self__, "instance_group_spec", instance_group_spec)
        if amount is not None:
            pulumi.set(__self__, "amount", amount)
        if auto_pay is not None:
            pulumi.set(__self__, "auto_pay", auto_pay)
        if auto_renew is not None:
            pulumi.set(__self__, "auto_renew", auto_renew)
        if charge_type is not None:
            pulumi.set(__self__, "charge_type", charge_type)
        if gpu_acceleration is not None:
            pulumi.set(__self__, "gpu_acceleration", gpu_acceleration)
        if instance_group_name is not None:
            pulumi.set(__self__, "instance_group_name", instance_group_name)
        if number_of_instances is not None:
            pulumi.set(__self__, "number_of_instances", number_of_instances)
        if office_site_id is not None:
            pulumi.set(__self__, "office_site_id", office_site_id)
        if period is not None:
            pulumi.set(__self__, "period", period)
        if period_unit is not None:
            pulumi.set(__self__, "period_unit", period_unit)
        if policy_group_id is not None:
            pulumi.set(__self__, "policy_group_id", policy_group_id)
        if vswitch_id is not None:
            pulumi.set(__self__, "vswitch_id", vswitch_id)

    @property
    @pulumi.getter(name="imageId")
    def image_id(self) -> pulumi.Input[builtins.str]:
        """
        The image ID.
        """
        return pulumi.get(self, "image_id")

    @image_id.setter
    def image_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "image_id", value)

    @property
    @pulumi.getter(name="instanceGroupSpec")
    def instance_group_spec(self) -> pulumi.Input[builtins.str]:
        """
        Instance group specifications.
        """
        return pulumi.get(self, "instance_group_spec")

    @instance_group_spec.setter
    def instance_group_spec(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "instance_group_spec", value)

    @property
    @pulumi.getter
    def amount(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The number of instance groups. The default value is 1 and the maximum value is 100.
        """
        return pulumi.get(self, "amount")

    @amount.setter
    def amount(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "amount", value)

    @property
    @pulumi.getter(name="autoPay")
    def auto_pay(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether to pay automatically. The default is false.
        """
        return pulumi.get(self, "auto_pay")

    @auto_pay.setter
    def auto_pay(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "auto_pay", value)

    @property
    @pulumi.getter(name="autoRenew")
    def auto_renew(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether to enable automatic renewal. The default is false.
        """
        return pulumi.get(self, "auto_renew")

    @auto_renew.setter
    def auto_renew(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "auto_renew", value)

    @property
    @pulumi.getter(name="chargeType")
    def charge_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The billing type.
        """
        return pulumi.get(self, "charge_type")

    @charge_type.setter
    def charge_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "charge_type", value)

    @property
    @pulumi.getter(name="gpuAcceleration")
    def gpu_acceleration(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether to enable GPU acceleration. The default value is false.
        - true: On.
        - false: closed.
        """
        return pulumi.get(self, "gpu_acceleration")

    @gpu_acceleration.setter
    def gpu_acceleration(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "gpu_acceleration", value)

    @property
    @pulumi.getter(name="instanceGroupName")
    def instance_group_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The instance group name

        > **NOTE:** >

        > **NOTE:** - The instance group name must be no more than 30 characters in length. Start with an uppercase/lowercase letter or Chinese. It cannot start with http:// or https://. Only Chinese, English, numbers, half-width colons (:), underscores (_), periods (.), or hyphens (-) are supported.
        """
        return pulumi.get(self, "instance_group_name")

    @instance_group_name.setter
    def instance_group_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_group_name", value)

    @property
    @pulumi.getter(name="numberOfInstances")
    def number_of_instances(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The number of instances in the instance group. The maximum value is 100.
        """
        return pulumi.get(self, "number_of_instances")

    @number_of_instances.setter
    def number_of_instances(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "number_of_instances", value)

    @property
    @pulumi.getter(name="officeSiteId")
    def office_site_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The network ID.
        - Create a shared network instance: Network ID is optional. Enter the network ID whose type is **Shared Network** on the [cloud mobile phone console> Network](https://wya.wuying.aliyun.com/network) page. If the console does not have a shared network, you can fill it in. A shared network is automatically created when the instance group is created.
        - Create a VPC instance: the network ID is required. Enter the network ID of `VPC` on the [cloud mobile phone console> Network](https://wya.wuying.aliyun.com/network) page. If the console does not have a VPC network, you need to create a network first.
        """
        return pulumi.get(self, "office_site_id")

    @office_site_id.setter
    def office_site_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "office_site_id", value)

    @property
    @pulumi.getter
    def period(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The duration of the resource purchase. The unit is specified by PeriodUnit.
        """
        return pulumi.get(self, "period")

    @period.setter
    def period(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "period", value)

    @property
    @pulumi.getter(name="periodUnit")
    def period_unit(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The unit of time for purchasing resources.
        """
        return pulumi.get(self, "period_unit")

    @period_unit.setter
    def period_unit(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "period_unit", value)

    @property
    @pulumi.getter(name="policyGroupId")
    def policy_group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The policy ID. You can query the list of policies by calling ListPolicyGroups.
        """
        return pulumi.get(self, "policy_group_id")

    @policy_group_id.setter
    def policy_group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "policy_group_id", value)

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The vSwitch ID.
        """
        return pulumi.get(self, "vswitch_id")

    @vswitch_id.setter
    def vswitch_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vswitch_id", value)


@pulumi.input_type
class _GroupState:
    def __init__(__self__, *,
                 amount: Optional[pulumi.Input[builtins.int]] = None,
                 auto_pay: Optional[pulumi.Input[builtins.bool]] = None,
                 auto_renew: Optional[pulumi.Input[builtins.bool]] = None,
                 charge_type: Optional[pulumi.Input[builtins.str]] = None,
                 gpu_acceleration: Optional[pulumi.Input[builtins.bool]] = None,
                 image_id: Optional[pulumi.Input[builtins.str]] = None,
                 instance_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 instance_group_spec: Optional[pulumi.Input[builtins.str]] = None,
                 number_of_instances: Optional[pulumi.Input[builtins.int]] = None,
                 office_site_id: Optional[pulumi.Input[builtins.str]] = None,
                 period: Optional[pulumi.Input[builtins.int]] = None,
                 period_unit: Optional[pulumi.Input[builtins.str]] = None,
                 policy_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 vswitch_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Group resources.
        :param pulumi.Input[builtins.int] amount: The number of instance groups. The default value is 1 and the maximum value is 100.
        :param pulumi.Input[builtins.bool] auto_pay: Whether to pay automatically. The default is false.
        :param pulumi.Input[builtins.bool] auto_renew: Whether to enable automatic renewal. The default is false.
        :param pulumi.Input[builtins.str] charge_type: The billing type.
        :param pulumi.Input[builtins.bool] gpu_acceleration: Whether to enable GPU acceleration. The default value is false.
               - true: On.
               - false: closed.
        :param pulumi.Input[builtins.str] image_id: The image ID.
        :param pulumi.Input[builtins.str] instance_group_name: The instance group name
               
               > **NOTE:** >
               
               > **NOTE:** - The instance group name must be no more than 30 characters in length. Start with an uppercase/lowercase letter or Chinese. It cannot start with http:// or https://. Only Chinese, English, numbers, half-width colons (:), underscores (_), periods (.), or hyphens (-) are supported.
        :param pulumi.Input[builtins.str] instance_group_spec: Instance group specifications.
        :param pulumi.Input[builtins.int] number_of_instances: The number of instances in the instance group. The maximum value is 100.
        :param pulumi.Input[builtins.str] office_site_id: The network ID.
               - Create a shared network instance: Network ID is optional. Enter the network ID whose type is **Shared Network** on the [cloud mobile phone console> Network](https://wya.wuying.aliyun.com/network) page. If the console does not have a shared network, you can fill it in. A shared network is automatically created when the instance group is created.
               - Create a VPC instance: the network ID is required. Enter the network ID of `VPC` on the [cloud mobile phone console> Network](https://wya.wuying.aliyun.com/network) page. If the console does not have a VPC network, you need to create a network first.
        :param pulumi.Input[builtins.int] period: The duration of the resource purchase. The unit is specified by PeriodUnit.
        :param pulumi.Input[builtins.str] period_unit: The unit of time for purchasing resources.
        :param pulumi.Input[builtins.str] policy_group_id: The policy ID. You can query the list of policies by calling ListPolicyGroups.
        :param pulumi.Input[builtins.str] status: Instance group status
        :param pulumi.Input[builtins.str] vswitch_id: The vSwitch ID.
        """
        if amount is not None:
            pulumi.set(__self__, "amount", amount)
        if auto_pay is not None:
            pulumi.set(__self__, "auto_pay", auto_pay)
        if auto_renew is not None:
            pulumi.set(__self__, "auto_renew", auto_renew)
        if charge_type is not None:
            pulumi.set(__self__, "charge_type", charge_type)
        if gpu_acceleration is not None:
            pulumi.set(__self__, "gpu_acceleration", gpu_acceleration)
        if image_id is not None:
            pulumi.set(__self__, "image_id", image_id)
        if instance_group_name is not None:
            pulumi.set(__self__, "instance_group_name", instance_group_name)
        if instance_group_spec is not None:
            pulumi.set(__self__, "instance_group_spec", instance_group_spec)
        if number_of_instances is not None:
            pulumi.set(__self__, "number_of_instances", number_of_instances)
        if office_site_id is not None:
            pulumi.set(__self__, "office_site_id", office_site_id)
        if period is not None:
            pulumi.set(__self__, "period", period)
        if period_unit is not None:
            pulumi.set(__self__, "period_unit", period_unit)
        if policy_group_id is not None:
            pulumi.set(__self__, "policy_group_id", policy_group_id)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if vswitch_id is not None:
            pulumi.set(__self__, "vswitch_id", vswitch_id)

    @property
    @pulumi.getter
    def amount(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The number of instance groups. The default value is 1 and the maximum value is 100.
        """
        return pulumi.get(self, "amount")

    @amount.setter
    def amount(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "amount", value)

    @property
    @pulumi.getter(name="autoPay")
    def auto_pay(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether to pay automatically. The default is false.
        """
        return pulumi.get(self, "auto_pay")

    @auto_pay.setter
    def auto_pay(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "auto_pay", value)

    @property
    @pulumi.getter(name="autoRenew")
    def auto_renew(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether to enable automatic renewal. The default is false.
        """
        return pulumi.get(self, "auto_renew")

    @auto_renew.setter
    def auto_renew(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "auto_renew", value)

    @property
    @pulumi.getter(name="chargeType")
    def charge_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The billing type.
        """
        return pulumi.get(self, "charge_type")

    @charge_type.setter
    def charge_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "charge_type", value)

    @property
    @pulumi.getter(name="gpuAcceleration")
    def gpu_acceleration(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether to enable GPU acceleration. The default value is false.
        - true: On.
        - false: closed.
        """
        return pulumi.get(self, "gpu_acceleration")

    @gpu_acceleration.setter
    def gpu_acceleration(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "gpu_acceleration", value)

    @property
    @pulumi.getter(name="imageId")
    def image_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The image ID.
        """
        return pulumi.get(self, "image_id")

    @image_id.setter
    def image_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "image_id", value)

    @property
    @pulumi.getter(name="instanceGroupName")
    def instance_group_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The instance group name

        > **NOTE:** >

        > **NOTE:** - The instance group name must be no more than 30 characters in length. Start with an uppercase/lowercase letter or Chinese. It cannot start with http:// or https://. Only Chinese, English, numbers, half-width colons (:), underscores (_), periods (.), or hyphens (-) are supported.
        """
        return pulumi.get(self, "instance_group_name")

    @instance_group_name.setter
    def instance_group_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_group_name", value)

    @property
    @pulumi.getter(name="instanceGroupSpec")
    def instance_group_spec(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Instance group specifications.
        """
        return pulumi.get(self, "instance_group_spec")

    @instance_group_spec.setter
    def instance_group_spec(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_group_spec", value)

    @property
    @pulumi.getter(name="numberOfInstances")
    def number_of_instances(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The number of instances in the instance group. The maximum value is 100.
        """
        return pulumi.get(self, "number_of_instances")

    @number_of_instances.setter
    def number_of_instances(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "number_of_instances", value)

    @property
    @pulumi.getter(name="officeSiteId")
    def office_site_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The network ID.
        - Create a shared network instance: Network ID is optional. Enter the network ID whose type is **Shared Network** on the [cloud mobile phone console> Network](https://wya.wuying.aliyun.com/network) page. If the console does not have a shared network, you can fill it in. A shared network is automatically created when the instance group is created.
        - Create a VPC instance: the network ID is required. Enter the network ID of `VPC` on the [cloud mobile phone console> Network](https://wya.wuying.aliyun.com/network) page. If the console does not have a VPC network, you need to create a network first.
        """
        return pulumi.get(self, "office_site_id")

    @office_site_id.setter
    def office_site_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "office_site_id", value)

    @property
    @pulumi.getter
    def period(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The duration of the resource purchase. The unit is specified by PeriodUnit.
        """
        return pulumi.get(self, "period")

    @period.setter
    def period(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "period", value)

    @property
    @pulumi.getter(name="periodUnit")
    def period_unit(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The unit of time for purchasing resources.
        """
        return pulumi.get(self, "period_unit")

    @period_unit.setter
    def period_unit(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "period_unit", value)

    @property
    @pulumi.getter(name="policyGroupId")
    def policy_group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The policy ID. You can query the list of policies by calling ListPolicyGroups.
        """
        return pulumi.get(self, "policy_group_id")

    @policy_group_id.setter
    def policy_group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "policy_group_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Instance group status
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The vSwitch ID.
        """
        return pulumi.get(self, "vswitch_id")

    @vswitch_id.setter
    def vswitch_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vswitch_id", value)


@pulumi.type_token("alicloud:cloudphoneinstance/group:Group")
class Group(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 amount: Optional[pulumi.Input[builtins.int]] = None,
                 auto_pay: Optional[pulumi.Input[builtins.bool]] = None,
                 auto_renew: Optional[pulumi.Input[builtins.bool]] = None,
                 charge_type: Optional[pulumi.Input[builtins.str]] = None,
                 gpu_acceleration: Optional[pulumi.Input[builtins.bool]] = None,
                 image_id: Optional[pulumi.Input[builtins.str]] = None,
                 instance_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 instance_group_spec: Optional[pulumi.Input[builtins.str]] = None,
                 number_of_instances: Optional[pulumi.Input[builtins.int]] = None,
                 office_site_id: Optional[pulumi.Input[builtins.str]] = None,
                 period: Optional[pulumi.Input[builtins.int]] = None,
                 period_unit: Optional[pulumi.Input[builtins.str]] = None,
                 policy_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 vswitch_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a Cloud Phone Instance Group resource.

        For information about Cloud Phone Instance Group and how to use it, see [What is Instance Group](https://next.api.alibabacloud.com/document/eds-aic/2023-09-30/CreateAndroidInstanceGroup).

        > **NOTE:** Available since v1.243.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        region_id = config.get("regionId")
        if region_id is None:
            region_id = "cn-hangzhou"
        defaultj_z1gi0 = alicloud.cloudphone.Policy("defaultjZ1gi0",
            lock_resolution="off",
            resolution_width=720,
            camera_redirect="on",
            policy_group_name="defaultPolicyGroup",
            resolution_height=1280,
            clipboard="readwrite",
            net_redirect_policy={
                "net_redirect": "off",
                "custom_proxy": "off",
            })
        default_h2a5_ks = alicloud.eds.SimpleOfficeSite("defaultH2a5KS",
            office_site_name="InitOfficeSite",
            cidr_block="172.16.0.0/12")
        default = alicloud.cloudphoneinstance.Group("default",
            instance_group_spec="acp.basic.small",
            instance_group_name="AutoCreateGroupName",
            period=1,
            number_of_instances=1,
            charge_type="PostPaid",
            image_id="imgc-075cllfeuazh03tg9",
            period_unit="Hour",
            auto_renew=False,
            amount=1,
            auto_pay=False,
            gpu_acceleration=False,
            policy_group_id=defaultj_z1gi0.id,
            office_site_id=default_h2a5_ks.id)
        ```

        ## Import

        Cloud Phone Instance Group can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:cloudphoneinstance/group:Group example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] amount: The number of instance groups. The default value is 1 and the maximum value is 100.
        :param pulumi.Input[builtins.bool] auto_pay: Whether to pay automatically. The default is false.
        :param pulumi.Input[builtins.bool] auto_renew: Whether to enable automatic renewal. The default is false.
        :param pulumi.Input[builtins.str] charge_type: The billing type.
        :param pulumi.Input[builtins.bool] gpu_acceleration: Whether to enable GPU acceleration. The default value is false.
               - true: On.
               - false: closed.
        :param pulumi.Input[builtins.str] image_id: The image ID.
        :param pulumi.Input[builtins.str] instance_group_name: The instance group name
               
               > **NOTE:** >
               
               > **NOTE:** - The instance group name must be no more than 30 characters in length. Start with an uppercase/lowercase letter or Chinese. It cannot start with http:// or https://. Only Chinese, English, numbers, half-width colons (:), underscores (_), periods (.), or hyphens (-) are supported.
        :param pulumi.Input[builtins.str] instance_group_spec: Instance group specifications.
        :param pulumi.Input[builtins.int] number_of_instances: The number of instances in the instance group. The maximum value is 100.
        :param pulumi.Input[builtins.str] office_site_id: The network ID.
               - Create a shared network instance: Network ID is optional. Enter the network ID whose type is **Shared Network** on the [cloud mobile phone console> Network](https://wya.wuying.aliyun.com/network) page. If the console does not have a shared network, you can fill it in. A shared network is automatically created when the instance group is created.
               - Create a VPC instance: the network ID is required. Enter the network ID of `VPC` on the [cloud mobile phone console> Network](https://wya.wuying.aliyun.com/network) page. If the console does not have a VPC network, you need to create a network first.
        :param pulumi.Input[builtins.int] period: The duration of the resource purchase. The unit is specified by PeriodUnit.
        :param pulumi.Input[builtins.str] period_unit: The unit of time for purchasing resources.
        :param pulumi.Input[builtins.str] policy_group_id: The policy ID. You can query the list of policies by calling ListPolicyGroups.
        :param pulumi.Input[builtins.str] vswitch_id: The vSwitch ID.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GroupArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Cloud Phone Instance Group resource.

        For information about Cloud Phone Instance Group and how to use it, see [What is Instance Group](https://next.api.alibabacloud.com/document/eds-aic/2023-09-30/CreateAndroidInstanceGroup).

        > **NOTE:** Available since v1.243.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        region_id = config.get("regionId")
        if region_id is None:
            region_id = "cn-hangzhou"
        defaultj_z1gi0 = alicloud.cloudphone.Policy("defaultjZ1gi0",
            lock_resolution="off",
            resolution_width=720,
            camera_redirect="on",
            policy_group_name="defaultPolicyGroup",
            resolution_height=1280,
            clipboard="readwrite",
            net_redirect_policy={
                "net_redirect": "off",
                "custom_proxy": "off",
            })
        default_h2a5_ks = alicloud.eds.SimpleOfficeSite("defaultH2a5KS",
            office_site_name="InitOfficeSite",
            cidr_block="172.16.0.0/12")
        default = alicloud.cloudphoneinstance.Group("default",
            instance_group_spec="acp.basic.small",
            instance_group_name="AutoCreateGroupName",
            period=1,
            number_of_instances=1,
            charge_type="PostPaid",
            image_id="imgc-075cllfeuazh03tg9",
            period_unit="Hour",
            auto_renew=False,
            amount=1,
            auto_pay=False,
            gpu_acceleration=False,
            policy_group_id=defaultj_z1gi0.id,
            office_site_id=default_h2a5_ks.id)
        ```

        ## Import

        Cloud Phone Instance Group can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:cloudphoneinstance/group:Group example <id>
        ```

        :param str resource_name: The name of the resource.
        :param GroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 amount: Optional[pulumi.Input[builtins.int]] = None,
                 auto_pay: Optional[pulumi.Input[builtins.bool]] = None,
                 auto_renew: Optional[pulumi.Input[builtins.bool]] = None,
                 charge_type: Optional[pulumi.Input[builtins.str]] = None,
                 gpu_acceleration: Optional[pulumi.Input[builtins.bool]] = None,
                 image_id: Optional[pulumi.Input[builtins.str]] = None,
                 instance_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 instance_group_spec: Optional[pulumi.Input[builtins.str]] = None,
                 number_of_instances: Optional[pulumi.Input[builtins.int]] = None,
                 office_site_id: Optional[pulumi.Input[builtins.str]] = None,
                 period: Optional[pulumi.Input[builtins.int]] = None,
                 period_unit: Optional[pulumi.Input[builtins.str]] = None,
                 policy_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 vswitch_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GroupArgs.__new__(GroupArgs)

            __props__.__dict__["amount"] = amount
            __props__.__dict__["auto_pay"] = auto_pay
            __props__.__dict__["auto_renew"] = auto_renew
            __props__.__dict__["charge_type"] = charge_type
            __props__.__dict__["gpu_acceleration"] = gpu_acceleration
            if image_id is None and not opts.urn:
                raise TypeError("Missing required property 'image_id'")
            __props__.__dict__["image_id"] = image_id
            __props__.__dict__["instance_group_name"] = instance_group_name
            if instance_group_spec is None and not opts.urn:
                raise TypeError("Missing required property 'instance_group_spec'")
            __props__.__dict__["instance_group_spec"] = instance_group_spec
            __props__.__dict__["number_of_instances"] = number_of_instances
            __props__.__dict__["office_site_id"] = office_site_id
            __props__.__dict__["period"] = period
            __props__.__dict__["period_unit"] = period_unit
            __props__.__dict__["policy_group_id"] = policy_group_id
            __props__.__dict__["vswitch_id"] = vswitch_id
            __props__.__dict__["status"] = None
        super(Group, __self__).__init__(
            'alicloud:cloudphoneinstance/group:Group',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            amount: Optional[pulumi.Input[builtins.int]] = None,
            auto_pay: Optional[pulumi.Input[builtins.bool]] = None,
            auto_renew: Optional[pulumi.Input[builtins.bool]] = None,
            charge_type: Optional[pulumi.Input[builtins.str]] = None,
            gpu_acceleration: Optional[pulumi.Input[builtins.bool]] = None,
            image_id: Optional[pulumi.Input[builtins.str]] = None,
            instance_group_name: Optional[pulumi.Input[builtins.str]] = None,
            instance_group_spec: Optional[pulumi.Input[builtins.str]] = None,
            number_of_instances: Optional[pulumi.Input[builtins.int]] = None,
            office_site_id: Optional[pulumi.Input[builtins.str]] = None,
            period: Optional[pulumi.Input[builtins.int]] = None,
            period_unit: Optional[pulumi.Input[builtins.str]] = None,
            policy_group_id: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            vswitch_id: Optional[pulumi.Input[builtins.str]] = None) -> 'Group':
        """
        Get an existing Group resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] amount: The number of instance groups. The default value is 1 and the maximum value is 100.
        :param pulumi.Input[builtins.bool] auto_pay: Whether to pay automatically. The default is false.
        :param pulumi.Input[builtins.bool] auto_renew: Whether to enable automatic renewal. The default is false.
        :param pulumi.Input[builtins.str] charge_type: The billing type.
        :param pulumi.Input[builtins.bool] gpu_acceleration: Whether to enable GPU acceleration. The default value is false.
               - true: On.
               - false: closed.
        :param pulumi.Input[builtins.str] image_id: The image ID.
        :param pulumi.Input[builtins.str] instance_group_name: The instance group name
               
               > **NOTE:** >
               
               > **NOTE:** - The instance group name must be no more than 30 characters in length. Start with an uppercase/lowercase letter or Chinese. It cannot start with http:// or https://. Only Chinese, English, numbers, half-width colons (:), underscores (_), periods (.), or hyphens (-) are supported.
        :param pulumi.Input[builtins.str] instance_group_spec: Instance group specifications.
        :param pulumi.Input[builtins.int] number_of_instances: The number of instances in the instance group. The maximum value is 100.
        :param pulumi.Input[builtins.str] office_site_id: The network ID.
               - Create a shared network instance: Network ID is optional. Enter the network ID whose type is **Shared Network** on the [cloud mobile phone console> Network](https://wya.wuying.aliyun.com/network) page. If the console does not have a shared network, you can fill it in. A shared network is automatically created when the instance group is created.
               - Create a VPC instance: the network ID is required. Enter the network ID of `VPC` on the [cloud mobile phone console> Network](https://wya.wuying.aliyun.com/network) page. If the console does not have a VPC network, you need to create a network first.
        :param pulumi.Input[builtins.int] period: The duration of the resource purchase. The unit is specified by PeriodUnit.
        :param pulumi.Input[builtins.str] period_unit: The unit of time for purchasing resources.
        :param pulumi.Input[builtins.str] policy_group_id: The policy ID. You can query the list of policies by calling ListPolicyGroups.
        :param pulumi.Input[builtins.str] status: Instance group status
        :param pulumi.Input[builtins.str] vswitch_id: The vSwitch ID.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GroupState.__new__(_GroupState)

        __props__.__dict__["amount"] = amount
        __props__.__dict__["auto_pay"] = auto_pay
        __props__.__dict__["auto_renew"] = auto_renew
        __props__.__dict__["charge_type"] = charge_type
        __props__.__dict__["gpu_acceleration"] = gpu_acceleration
        __props__.__dict__["image_id"] = image_id
        __props__.__dict__["instance_group_name"] = instance_group_name
        __props__.__dict__["instance_group_spec"] = instance_group_spec
        __props__.__dict__["number_of_instances"] = number_of_instances
        __props__.__dict__["office_site_id"] = office_site_id
        __props__.__dict__["period"] = period
        __props__.__dict__["period_unit"] = period_unit
        __props__.__dict__["policy_group_id"] = policy_group_id
        __props__.__dict__["status"] = status
        __props__.__dict__["vswitch_id"] = vswitch_id
        return Group(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def amount(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        The number of instance groups. The default value is 1 and the maximum value is 100.
        """
        return pulumi.get(self, "amount")

    @property
    @pulumi.getter(name="autoPay")
    def auto_pay(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Whether to pay automatically. The default is false.
        """
        return pulumi.get(self, "auto_pay")

    @property
    @pulumi.getter(name="autoRenew")
    def auto_renew(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Whether to enable automatic renewal. The default is false.
        """
        return pulumi.get(self, "auto_renew")

    @property
    @pulumi.getter(name="chargeType")
    def charge_type(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The billing type.
        """
        return pulumi.get(self, "charge_type")

    @property
    @pulumi.getter(name="gpuAcceleration")
    def gpu_acceleration(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Whether to enable GPU acceleration. The default value is false.
        - true: On.
        - false: closed.
        """
        return pulumi.get(self, "gpu_acceleration")

    @property
    @pulumi.getter(name="imageId")
    def image_id(self) -> pulumi.Output[builtins.str]:
        """
        The image ID.
        """
        return pulumi.get(self, "image_id")

    @property
    @pulumi.getter(name="instanceGroupName")
    def instance_group_name(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The instance group name

        > **NOTE:** >

        > **NOTE:** - The instance group name must be no more than 30 characters in length. Start with an uppercase/lowercase letter or Chinese. It cannot start with http:// or https://. Only Chinese, English, numbers, half-width colons (:), underscores (_), periods (.), or hyphens (-) are supported.
        """
        return pulumi.get(self, "instance_group_name")

    @property
    @pulumi.getter(name="instanceGroupSpec")
    def instance_group_spec(self) -> pulumi.Output[builtins.str]:
        """
        Instance group specifications.
        """
        return pulumi.get(self, "instance_group_spec")

    @property
    @pulumi.getter(name="numberOfInstances")
    def number_of_instances(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        The number of instances in the instance group. The maximum value is 100.
        """
        return pulumi.get(self, "number_of_instances")

    @property
    @pulumi.getter(name="officeSiteId")
    def office_site_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The network ID.
        - Create a shared network instance: Network ID is optional. Enter the network ID whose type is **Shared Network** on the [cloud mobile phone console> Network](https://wya.wuying.aliyun.com/network) page. If the console does not have a shared network, you can fill it in. A shared network is automatically created when the instance group is created.
        - Create a VPC instance: the network ID is required. Enter the network ID of `VPC` on the [cloud mobile phone console> Network](https://wya.wuying.aliyun.com/network) page. If the console does not have a VPC network, you need to create a network first.
        """
        return pulumi.get(self, "office_site_id")

    @property
    @pulumi.getter
    def period(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        The duration of the resource purchase. The unit is specified by PeriodUnit.
        """
        return pulumi.get(self, "period")

    @property
    @pulumi.getter(name="periodUnit")
    def period_unit(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The unit of time for purchasing resources.
        """
        return pulumi.get(self, "period_unit")

    @property
    @pulumi.getter(name="policyGroupId")
    def policy_group_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The policy ID. You can query the list of policies by calling ListPolicyGroups.
        """
        return pulumi.get(self, "policy_group_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        Instance group status
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The vSwitch ID.
        """
        return pulumi.get(self, "vswitch_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['FlowPipelineArgs', 'FlowPipeline']

@pulumi.input_type
class FlowPipelineArgs:
    def __init__(__self__, *,
                 manifest: pulumi.Input[builtins.str],
                 workspace_id: pulumi.Input[builtins.str]):
        """
        The set of arguments for constructing a FlowPipeline resource.
        :param pulumi.Input[builtins.str] manifest: The pipeline definition. For more information, see the sample pipeline definition).
        :param pulumi.Input[builtins.str] workspace_id: The ID of the workspace.
        """
        pulumi.set(__self__, "manifest", manifest)
        pulumi.set(__self__, "workspace_id", workspace_id)

    @property
    @pulumi.getter
    def manifest(self) -> pulumi.Input[builtins.str]:
        """
        The pipeline definition. For more information, see the sample pipeline definition).
        """
        return pulumi.get(self, "manifest")

    @manifest.setter
    def manifest(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "manifest", value)

    @property
    @pulumi.getter(name="workspaceId")
    def workspace_id(self) -> pulumi.Input[builtins.str]:
        """
        The ID of the workspace.
        """
        return pulumi.get(self, "workspace_id")

    @workspace_id.setter
    def workspace_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "workspace_id", value)


@pulumi.input_type
class _FlowPipelineState:
    def __init__(__self__, *,
                 create_time: Optional[pulumi.Input[builtins.str]] = None,
                 manifest: Optional[pulumi.Input[builtins.str]] = None,
                 workspace_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering FlowPipeline resources.
        :param pulumi.Input[builtins.str] create_time: The creation time of the resource.
        :param pulumi.Input[builtins.str] manifest: The pipeline definition. For more information, see the sample pipeline definition).
        :param pulumi.Input[builtins.str] workspace_id: The ID of the workspace.
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if manifest is not None:
            pulumi.set(__self__, "manifest", manifest)
        if workspace_id is not None:
            pulumi.set(__self__, "workspace_id", workspace_id)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The creation time of the resource.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter
    def manifest(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The pipeline definition. For more information, see the sample pipeline definition).
        """
        return pulumi.get(self, "manifest")

    @manifest.setter
    def manifest(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "manifest", value)

    @property
    @pulumi.getter(name="workspaceId")
    def workspace_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the workspace.
        """
        return pulumi.get(self, "workspace_id")

    @workspace_id.setter
    def workspace_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "workspace_id", value)


@pulumi.type_token("alicloud:pai/flowPipeline:FlowPipeline")
class FlowPipeline(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 manifest: Optional[pulumi.Input[builtins.str]] = None,
                 workspace_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a Pai Flow Pipeline resource.

        For information about Pai Flow Pipeline and how to use it, see [What is Pipeline](https://www.alibabacloud.com/help/en/pai/developer-reference/api-paiflow-2021-02-02-createpipeline).

        > **NOTE:** Available since v1.248.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform_example"
        default = alicloud.get_account()
        default_integer = random.index.Integer("default",
            min=10000,
            max=99999)
        default_wj_qd1e = alicloud.pai.WorkspaceWorkspace("defaultWjQD1e",
            description=name,
            display_name=name,
            workspace_name=name,
            env_types=["dev"])
        default_flow_pipeline = alicloud.pai.FlowPipeline("default",
            workspace_id=default_wj_qd1e.id,
            manifest=f\"\"\"apiVersion: "core/v1"
        metadata:
          provider: "{default.id}"
          version: "v1"
          identifier: "my_pipeline"
          name: "source-transform"
          uuid: "terraformuuid{default_integer["result"]}"
          annotations: {{}}
          labels: {{}}
        spec:
          inputs:
            artifacts: []
            parameters:
            - name: "execution_maxcompute"
              type: "Map"
              value:
                spec:
                  endpoint: "http://service.cn.maxcompute.aliyun-inc.com/api"
                  odpsProject: "test_i****"
          outputs:
            artifacts: []
            parameters: []
          arguments:
            artifacts: []
            parameters: []
          dependencies: []
          initContainers: []
          sideCarContainers: []
          pipelines:
          - apiVersion: "core/v1"
            metadata:
              provider: "pai"
              version: "v1"
              identifier: "data_source"
              name: "data-source"
              uuid: "2ftahdnzcod2rt6u9q"
              displayName: "读数据表-1"
              annotations: {{}}
              labels: {{}}
            spec:
              inputs:
                artifacts: []
                parameters: []
              outputs:
                artifacts: []
                parameters: []
              arguments:
                artifacts: []
                parameters:
                - name: "inputTableName"
                  value: "pai_online_project.wumai_data"
                - name: "execution"
                  from: "{{{{inputs.parameters.execution_maxcompute}}}}"
              dependencies: []
              initContainers: []
              sideCarContainers: []
              pipelines: []
              volumes: []
          - apiVersion: "core/v1"
            metadata:
              provider: "pai"
              version: "v1"
              identifier: "type_transform"
              name: "type-transform"
              uuid: "gacnnnl4ksvbabfh6l"
              displayName: "类型转换-1"
              annotations: {{}}
              labels: {{}}
            spec:
              inputs:
                artifacts: []
                parameters: []
              outputs:
                artifacts: []
                parameters: []
              arguments:
                artifacts:
                - name: "inputTable"
                  from: "{{{{pipelines.data_source.outputs.artifacts.outputTable}}}}"
                parameters:
                - name: "cols_to_double"
                  value: "time,hour,pm2,pm10,so2,co,no2"
                - name: "execution"
                  from: "{{{{inputs.parameters.execution_maxcompute}}}}"
              dependencies:
              - "data_source"
              initContainers: []
              sideCarContainers: []
              pipelines: []
              volumes: []
          volumes: []
        \"\"\")
        ```

        ## Import

        Pai Flow Pipeline can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:pai/flowPipeline:FlowPipeline example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] manifest: The pipeline definition. For more information, see the sample pipeline definition).
        :param pulumi.Input[builtins.str] workspace_id: The ID of the workspace.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: FlowPipelineArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Pai Flow Pipeline resource.

        For information about Pai Flow Pipeline and how to use it, see [What is Pipeline](https://www.alibabacloud.com/help/en/pai/developer-reference/api-paiflow-2021-02-02-createpipeline).

        > **NOTE:** Available since v1.248.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform_example"
        default = alicloud.get_account()
        default_integer = random.index.Integer("default",
            min=10000,
            max=99999)
        default_wj_qd1e = alicloud.pai.WorkspaceWorkspace("defaultWjQD1e",
            description=name,
            display_name=name,
            workspace_name=name,
            env_types=["dev"])
        default_flow_pipeline = alicloud.pai.FlowPipeline("default",
            workspace_id=default_wj_qd1e.id,
            manifest=f\"\"\"apiVersion: "core/v1"
        metadata:
          provider: "{default.id}"
          version: "v1"
          identifier: "my_pipeline"
          name: "source-transform"
          uuid: "terraformuuid{default_integer["result"]}"
          annotations: {{}}
          labels: {{}}
        spec:
          inputs:
            artifacts: []
            parameters:
            - name: "execution_maxcompute"
              type: "Map"
              value:
                spec:
                  endpoint: "http://service.cn.maxcompute.aliyun-inc.com/api"
                  odpsProject: "test_i****"
          outputs:
            artifacts: []
            parameters: []
          arguments:
            artifacts: []
            parameters: []
          dependencies: []
          initContainers: []
          sideCarContainers: []
          pipelines:
          - apiVersion: "core/v1"
            metadata:
              provider: "pai"
              version: "v1"
              identifier: "data_source"
              name: "data-source"
              uuid: "2ftahdnzcod2rt6u9q"
              displayName: "读数据表-1"
              annotations: {{}}
              labels: {{}}
            spec:
              inputs:
                artifacts: []
                parameters: []
              outputs:
                artifacts: []
                parameters: []
              arguments:
                artifacts: []
                parameters:
                - name: "inputTableName"
                  value: "pai_online_project.wumai_data"
                - name: "execution"
                  from: "{{{{inputs.parameters.execution_maxcompute}}}}"
              dependencies: []
              initContainers: []
              sideCarContainers: []
              pipelines: []
              volumes: []
          - apiVersion: "core/v1"
            metadata:
              provider: "pai"
              version: "v1"
              identifier: "type_transform"
              name: "type-transform"
              uuid: "gacnnnl4ksvbabfh6l"
              displayName: "类型转换-1"
              annotations: {{}}
              labels: {{}}
            spec:
              inputs:
                artifacts: []
                parameters: []
              outputs:
                artifacts: []
                parameters: []
              arguments:
                artifacts:
                - name: "inputTable"
                  from: "{{{{pipelines.data_source.outputs.artifacts.outputTable}}}}"
                parameters:
                - name: "cols_to_double"
                  value: "time,hour,pm2,pm10,so2,co,no2"
                - name: "execution"
                  from: "{{{{inputs.parameters.execution_maxcompute}}}}"
              dependencies:
              - "data_source"
              initContainers: []
              sideCarContainers: []
              pipelines: []
              volumes: []
          volumes: []
        \"\"\")
        ```

        ## Import

        Pai Flow Pipeline can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:pai/flowPipeline:FlowPipeline example <id>
        ```

        :param str resource_name: The name of the resource.
        :param FlowPipelineArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(FlowPipelineArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 manifest: Optional[pulumi.Input[builtins.str]] = None,
                 workspace_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = FlowPipelineArgs.__new__(FlowPipelineArgs)

            if manifest is None and not opts.urn:
                raise TypeError("Missing required property 'manifest'")
            __props__.__dict__["manifest"] = manifest
            if workspace_id is None and not opts.urn:
                raise TypeError("Missing required property 'workspace_id'")
            __props__.__dict__["workspace_id"] = workspace_id
            __props__.__dict__["create_time"] = None
        super(FlowPipeline, __self__).__init__(
            'alicloud:pai/flowPipeline:FlowPipeline',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            create_time: Optional[pulumi.Input[builtins.str]] = None,
            manifest: Optional[pulumi.Input[builtins.str]] = None,
            workspace_id: Optional[pulumi.Input[builtins.str]] = None) -> 'FlowPipeline':
        """
        Get an existing FlowPipeline resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] create_time: The creation time of the resource.
        :param pulumi.Input[builtins.str] manifest: The pipeline definition. For more information, see the sample pipeline definition).
        :param pulumi.Input[builtins.str] workspace_id: The ID of the workspace.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _FlowPipelineState.__new__(_FlowPipelineState)

        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["manifest"] = manifest
        __props__.__dict__["workspace_id"] = workspace_id
        return FlowPipeline(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[builtins.str]:
        """
        The creation time of the resource.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def manifest(self) -> pulumi.Output[builtins.str]:
        """
        The pipeline definition. For more information, see the sample pipeline definition).
        """
        return pulumi.get(self, "manifest")

    @property
    @pulumi.getter(name="workspaceId")
    def workspace_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the workspace.
        """
        return pulumi.get(self, "workspace_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ClientInstanceAttachmentArgs', 'ClientInstanceAttachment']

@pulumi.input_type
class ClientInstanceAttachmentArgs:
    def __init__(__self__, *,
                 client_instance_id: pulumi.Input[builtins.str],
                 instance_id: pulumi.Input[builtins.str],
                 category: Optional[pulumi.Input[builtins.str]] = None,
                 ei_instance_type: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a ClientInstanceAttachment resource.
        :param pulumi.Input[builtins.str] client_instance_id: The ID of the ECS or ECI instance bound to the EAIS instance.
        :param pulumi.Input[builtins.str] instance_id: The EAIS instance ID.
        :param pulumi.Input[builtins.str] category: EAIS instance category, valid values: `eais`, `ei`, default is `eais`.
        :param pulumi.Input[builtins.str] ei_instance_type: The Ei instance specification, which is used to filter matching specifications for updating.
        :param pulumi.Input[builtins.str] status: The status of the resource
        """
        pulumi.set(__self__, "client_instance_id", client_instance_id)
        pulumi.set(__self__, "instance_id", instance_id)
        if category is not None:
            pulumi.set(__self__, "category", category)
        if ei_instance_type is not None:
            pulumi.set(__self__, "ei_instance_type", ei_instance_type)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="clientInstanceId")
    def client_instance_id(self) -> pulumi.Input[builtins.str]:
        """
        The ID of the ECS or ECI instance bound to the EAIS instance.
        """
        return pulumi.get(self, "client_instance_id")

    @client_instance_id.setter
    def client_instance_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "client_instance_id", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Input[builtins.str]:
        """
        The EAIS instance ID.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter
    def category(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        EAIS instance category, valid values: `eais`, `ei`, default is `eais`.
        """
        return pulumi.get(self, "category")

    @category.setter
    def category(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "category", value)

    @property
    @pulumi.getter(name="eiInstanceType")
    def ei_instance_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The Ei instance specification, which is used to filter matching specifications for updating.
        """
        return pulumi.get(self, "ei_instance_type")

    @ei_instance_type.setter
    def ei_instance_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ei_instance_type", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The status of the resource
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.input_type
class _ClientInstanceAttachmentState:
    def __init__(__self__, *,
                 category: Optional[pulumi.Input[builtins.str]] = None,
                 client_instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 create_time: Optional[pulumi.Input[builtins.str]] = None,
                 ei_instance_type: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 region_id: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering ClientInstanceAttachment resources.
        :param pulumi.Input[builtins.str] category: EAIS instance category, valid values: `eais`, `ei`, default is `eais`.
        :param pulumi.Input[builtins.str] client_instance_id: The ID of the ECS or ECI instance bound to the EAIS instance.
        :param pulumi.Input[builtins.str] create_time: The creation time of the resource
        :param pulumi.Input[builtins.str] ei_instance_type: The Ei instance specification, which is used to filter matching specifications for updating.
        :param pulumi.Input[builtins.str] instance_id: The EAIS instance ID.
        :param pulumi.Input[builtins.str] region_id: The region ID of the resource
        :param pulumi.Input[builtins.str] status: The status of the resource
        """
        if category is not None:
            pulumi.set(__self__, "category", category)
        if client_instance_id is not None:
            pulumi.set(__self__, "client_instance_id", client_instance_id)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if ei_instance_type is not None:
            pulumi.set(__self__, "ei_instance_type", ei_instance_type)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if region_id is not None:
            pulumi.set(__self__, "region_id", region_id)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter
    def category(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        EAIS instance category, valid values: `eais`, `ei`, default is `eais`.
        """
        return pulumi.get(self, "category")

    @category.setter
    def category(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "category", value)

    @property
    @pulumi.getter(name="clientInstanceId")
    def client_instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the ECS or ECI instance bound to the EAIS instance.
        """
        return pulumi.get(self, "client_instance_id")

    @client_instance_id.setter
    def client_instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "client_instance_id", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The creation time of the resource
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="eiInstanceType")
    def ei_instance_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The Ei instance specification, which is used to filter matching specifications for updating.
        """
        return pulumi.get(self, "ei_instance_type")

    @ei_instance_type.setter
    def ei_instance_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ei_instance_type", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The EAIS instance ID.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="regionId")
    def region_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The region ID of the resource
        """
        return pulumi.get(self, "region_id")

    @region_id.setter
    def region_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "region_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The status of the resource
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.type_token("alicloud:eais/clientInstanceAttachment:ClientInstanceAttachment")
class ClientInstanceAttachment(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 category: Optional[pulumi.Input[builtins.str]] = None,
                 client_instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 ei_instance_type: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        ## Import

        EAIS Client Instance Attachment can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:eais/clientInstanceAttachment:ClientInstanceAttachment example <instance_id>:<client_instance_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] category: EAIS instance category, valid values: `eais`, `ei`, default is `eais`.
        :param pulumi.Input[builtins.str] client_instance_id: The ID of the ECS or ECI instance bound to the EAIS instance.
        :param pulumi.Input[builtins.str] ei_instance_type: The Ei instance specification, which is used to filter matching specifications for updating.
        :param pulumi.Input[builtins.str] instance_id: The EAIS instance ID.
        :param pulumi.Input[builtins.str] status: The status of the resource
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ClientInstanceAttachmentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Import

        EAIS Client Instance Attachment can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:eais/clientInstanceAttachment:ClientInstanceAttachment example <instance_id>:<client_instance_id>
        ```

        :param str resource_name: The name of the resource.
        :param ClientInstanceAttachmentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ClientInstanceAttachmentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 category: Optional[pulumi.Input[builtins.str]] = None,
                 client_instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 ei_instance_type: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ClientInstanceAttachmentArgs.__new__(ClientInstanceAttachmentArgs)

            __props__.__dict__["category"] = category
            if client_instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'client_instance_id'")
            __props__.__dict__["client_instance_id"] = client_instance_id
            __props__.__dict__["ei_instance_type"] = ei_instance_type
            if instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'instance_id'")
            __props__.__dict__["instance_id"] = instance_id
            __props__.__dict__["status"] = status
            __props__.__dict__["create_time"] = None
            __props__.__dict__["region_id"] = None
        super(ClientInstanceAttachment, __self__).__init__(
            'alicloud:eais/clientInstanceAttachment:ClientInstanceAttachment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            category: Optional[pulumi.Input[builtins.str]] = None,
            client_instance_id: Optional[pulumi.Input[builtins.str]] = None,
            create_time: Optional[pulumi.Input[builtins.str]] = None,
            ei_instance_type: Optional[pulumi.Input[builtins.str]] = None,
            instance_id: Optional[pulumi.Input[builtins.str]] = None,
            region_id: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None) -> 'ClientInstanceAttachment':
        """
        Get an existing ClientInstanceAttachment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] category: EAIS instance category, valid values: `eais`, `ei`, default is `eais`.
        :param pulumi.Input[builtins.str] client_instance_id: The ID of the ECS or ECI instance bound to the EAIS instance.
        :param pulumi.Input[builtins.str] create_time: The creation time of the resource
        :param pulumi.Input[builtins.str] ei_instance_type: The Ei instance specification, which is used to filter matching specifications for updating.
        :param pulumi.Input[builtins.str] instance_id: The EAIS instance ID.
        :param pulumi.Input[builtins.str] region_id: The region ID of the resource
        :param pulumi.Input[builtins.str] status: The status of the resource
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ClientInstanceAttachmentState.__new__(_ClientInstanceAttachmentState)

        __props__.__dict__["category"] = category
        __props__.__dict__["client_instance_id"] = client_instance_id
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["ei_instance_type"] = ei_instance_type
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["region_id"] = region_id
        __props__.__dict__["status"] = status
        return ClientInstanceAttachment(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def category(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        EAIS instance category, valid values: `eais`, `ei`, default is `eais`.
        """
        return pulumi.get(self, "category")

    @property
    @pulumi.getter(name="clientInstanceId")
    def client_instance_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the ECS or ECI instance bound to the EAIS instance.
        """
        return pulumi.get(self, "client_instance_id")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[builtins.str]:
        """
        The creation time of the resource
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="eiInstanceType")
    def ei_instance_type(self) -> pulumi.Output[builtins.str]:
        """
        The Ei instance specification, which is used to filter matching specifications for updating.
        """
        return pulumi.get(self, "ei_instance_type")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[builtins.str]:
        """
        The EAIS instance ID.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="regionId")
    def region_id(self) -> pulumi.Output[builtins.str]:
        """
        The region ID of the resource
        """
        return pulumi.get(self, "region_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        The status of the resource
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['RoleUserAttachmentArgs', 'RoleUserAttachment']

@pulumi.input_type
class RoleUserAttachmentArgs:
    def __init__(__self__, *,
                 project_name: pulumi.Input[builtins.str],
                 role_name: pulumi.Input[builtins.str],
                 user: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a RoleUserAttachment resource.
        :param pulumi.Input[builtins.str] project_name: Project Name
        :param pulumi.Input[builtins.str] role_name: Role Name, Valid Values: super_administrator, admin, Custom Role
               
               > **NOTE:** -- super_administrator: the built-in management role of MaxCompute. The Super Administrator of the project has the permission to operate all resources in the project and the management permission. Project owners or users with the Super_Administrator role can assign the Super_Administrator role to other users. -- admin: the built-in management role of MaxCompute, which has the permission to operate all resources in the project and some basic management permissions. Project owners can assign the Admin role to other users. -- Custom role: a role that is not built-in to MaxCompute and needs to be customized. You can refer to the role (starting with role_) definition in DataWorks.
        :param pulumi.Input[builtins.str] user: Supported input: Alibaba Cloud account, RAM user, and RAM role
               
               > **NOTE:** -- Alibaba Cloud account: the account registered on the Alibaba Cloud official website. - RAM User: a user created by an Alibaba Cloud account to assist the Alibaba Cloud account to complete data processing. -- RAM role: a RAM role, like a RAM user, is a type of RAM identity. A RAM role is a virtual user that does not have a specific identity authentication key and needs to be played by a trusted entity user for normal use.
        """
        pulumi.set(__self__, "project_name", project_name)
        pulumi.set(__self__, "role_name", role_name)
        if user is not None:
            pulumi.set(__self__, "user", user)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Input[builtins.str]:
        """
        Project Name
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="roleName")
    def role_name(self) -> pulumi.Input[builtins.str]:
        """
        Role Name, Valid Values: super_administrator, admin, Custom Role

        > **NOTE:** -- super_administrator: the built-in management role of MaxCompute. The Super Administrator of the project has the permission to operate all resources in the project and the management permission. Project owners or users with the Super_Administrator role can assign the Super_Administrator role to other users. -- admin: the built-in management role of MaxCompute, which has the permission to operate all resources in the project and some basic management permissions. Project owners can assign the Admin role to other users. -- Custom role: a role that is not built-in to MaxCompute and needs to be customized. You can refer to the role (starting with role_) definition in DataWorks.
        """
        return pulumi.get(self, "role_name")

    @role_name.setter
    def role_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "role_name", value)

    @property
    @pulumi.getter
    def user(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Supported input: Alibaba Cloud account, RAM user, and RAM role

        > **NOTE:** -- Alibaba Cloud account: the account registered on the Alibaba Cloud official website. - RAM User: a user created by an Alibaba Cloud account to assist the Alibaba Cloud account to complete data processing. -- RAM role: a RAM role, like a RAM user, is a type of RAM identity. A RAM role is a virtual user that does not have a specific identity authentication key and needs to be played by a trusted entity user for normal use.
        """
        return pulumi.get(self, "user")

    @user.setter
    def user(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "user", value)


@pulumi.input_type
class _RoleUserAttachmentState:
    def __init__(__self__, *,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 role_name: Optional[pulumi.Input[builtins.str]] = None,
                 user: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering RoleUserAttachment resources.
        :param pulumi.Input[builtins.str] project_name: Project Name
        :param pulumi.Input[builtins.str] role_name: Role Name, Valid Values: super_administrator, admin, Custom Role
               
               > **NOTE:** -- super_administrator: the built-in management role of MaxCompute. The Super Administrator of the project has the permission to operate all resources in the project and the management permission. Project owners or users with the Super_Administrator role can assign the Super_Administrator role to other users. -- admin: the built-in management role of MaxCompute, which has the permission to operate all resources in the project and some basic management permissions. Project owners can assign the Admin role to other users. -- Custom role: a role that is not built-in to MaxCompute and needs to be customized. You can refer to the role (starting with role_) definition in DataWorks.
        :param pulumi.Input[builtins.str] user: Supported input: Alibaba Cloud account, RAM user, and RAM role
               
               > **NOTE:** -- Alibaba Cloud account: the account registered on the Alibaba Cloud official website. - RAM User: a user created by an Alibaba Cloud account to assist the Alibaba Cloud account to complete data processing. -- RAM role: a RAM role, like a RAM user, is a type of RAM identity. A RAM role is a virtual user that does not have a specific identity authentication key and needs to be played by a trusted entity user for normal use.
        """
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if role_name is not None:
            pulumi.set(__self__, "role_name", role_name)
        if user is not None:
            pulumi.set(__self__, "user", user)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Project Name
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="roleName")
    def role_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Role Name, Valid Values: super_administrator, admin, Custom Role

        > **NOTE:** -- super_administrator: the built-in management role of MaxCompute. The Super Administrator of the project has the permission to operate all resources in the project and the management permission. Project owners or users with the Super_Administrator role can assign the Super_Administrator role to other users. -- admin: the built-in management role of MaxCompute, which has the permission to operate all resources in the project and some basic management permissions. Project owners can assign the Admin role to other users. -- Custom role: a role that is not built-in to MaxCompute and needs to be customized. You can refer to the role (starting with role_) definition in DataWorks.
        """
        return pulumi.get(self, "role_name")

    @role_name.setter
    def role_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "role_name", value)

    @property
    @pulumi.getter
    def user(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Supported input: Alibaba Cloud account, RAM user, and RAM role

        > **NOTE:** -- Alibaba Cloud account: the account registered on the Alibaba Cloud official website. - RAM User: a user created by an Alibaba Cloud account to assist the Alibaba Cloud account to complete data processing. -- RAM role: a RAM role, like a RAM user, is a type of RAM identity. A RAM role is a virtual user that does not have a specific identity authentication key and needs to be played by a trusted entity user for normal use.
        """
        return pulumi.get(self, "user")

    @user.setter
    def user(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "user", value)


@pulumi.type_token("alicloud:maxcompute/roleUserAttachment:RoleUserAttachment")
class RoleUserAttachment(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 role_name: Optional[pulumi.Input[builtins.str]] = None,
                 user: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a Max Compute Role User Attachment resource.

        Resources associated with a user and a project-level role.

        For information about Max Compute Role User Attachment and how to use it, see [What is Role User Attachment](https://www.alibabacloud.com/help/en/).

        > **NOTE:** Available since v1.242.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        aliyun_user = config.get("aliyunUser")
        if aliyun_user is None:
            aliyun_user = "ALIYUN$openapiautomation@test.aliyunid.com"
        ram_user = config.get("ramUser")
        if ram_user is None:
            ram_user = "RAM$openapiautomation@test.aliyunid.com:tf-example"
        ram_role = config.get("ramRole")
        if ram_role is None:
            ram_role = "RAM$openapiautomation@test.aliyunid.com:role/terraform-no-ak-assumerole-no-deleting"
        role_name = config.get("roleName")
        if role_name is None:
            role_name = "role_project_admin"
        project_name = config.get("projectName")
        if project_name is None:
            project_name = "default_project_669886c"
        default = alicloud.maxcompute.RoleUserAttachment("default",
            role_name=role_name,
            user=ram_role,
            project_name=project_name)
        ```

        ## Import

        Max Compute Role User Attachment can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:maxcompute/roleUserAttachment:RoleUserAttachment example <project_name>-<role_name>-<user>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] project_name: Project Name
        :param pulumi.Input[builtins.str] role_name: Role Name, Valid Values: super_administrator, admin, Custom Role
               
               > **NOTE:** -- super_administrator: the built-in management role of MaxCompute. The Super Administrator of the project has the permission to operate all resources in the project and the management permission. Project owners or users with the Super_Administrator role can assign the Super_Administrator role to other users. -- admin: the built-in management role of MaxCompute, which has the permission to operate all resources in the project and some basic management permissions. Project owners can assign the Admin role to other users. -- Custom role: a role that is not built-in to MaxCompute and needs to be customized. You can refer to the role (starting with role_) definition in DataWorks.
        :param pulumi.Input[builtins.str] user: Supported input: Alibaba Cloud account, RAM user, and RAM role
               
               > **NOTE:** -- Alibaba Cloud account: the account registered on the Alibaba Cloud official website. - RAM User: a user created by an Alibaba Cloud account to assist the Alibaba Cloud account to complete data processing. -- RAM role: a RAM role, like a RAM user, is a type of RAM identity. A RAM role is a virtual user that does not have a specific identity authentication key and needs to be played by a trusted entity user for normal use.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RoleUserAttachmentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Max Compute Role User Attachment resource.

        Resources associated with a user and a project-level role.

        For information about Max Compute Role User Attachment and how to use it, see [What is Role User Attachment](https://www.alibabacloud.com/help/en/).

        > **NOTE:** Available since v1.242.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        aliyun_user = config.get("aliyunUser")
        if aliyun_user is None:
            aliyun_user = "ALIYUN$openapiautomation@test.aliyunid.com"
        ram_user = config.get("ramUser")
        if ram_user is None:
            ram_user = "RAM$openapiautomation@test.aliyunid.com:tf-example"
        ram_role = config.get("ramRole")
        if ram_role is None:
            ram_role = "RAM$openapiautomation@test.aliyunid.com:role/terraform-no-ak-assumerole-no-deleting"
        role_name = config.get("roleName")
        if role_name is None:
            role_name = "role_project_admin"
        project_name = config.get("projectName")
        if project_name is None:
            project_name = "default_project_669886c"
        default = alicloud.maxcompute.RoleUserAttachment("default",
            role_name=role_name,
            user=ram_role,
            project_name=project_name)
        ```

        ## Import

        Max Compute Role User Attachment can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:maxcompute/roleUserAttachment:RoleUserAttachment example <project_name>-<role_name>-<user>
        ```

        :param str resource_name: The name of the resource.
        :param RoleUserAttachmentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RoleUserAttachmentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 role_name: Optional[pulumi.Input[builtins.str]] = None,
                 user: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RoleUserAttachmentArgs.__new__(RoleUserAttachmentArgs)

            if project_name is None and not opts.urn:
                raise TypeError("Missing required property 'project_name'")
            __props__.__dict__["project_name"] = project_name
            if role_name is None and not opts.urn:
                raise TypeError("Missing required property 'role_name'")
            __props__.__dict__["role_name"] = role_name
            __props__.__dict__["user"] = user
        super(RoleUserAttachment, __self__).__init__(
            'alicloud:maxcompute/roleUserAttachment:RoleUserAttachment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            role_name: Optional[pulumi.Input[builtins.str]] = None,
            user: Optional[pulumi.Input[builtins.str]] = None) -> 'RoleUserAttachment':
        """
        Get an existing RoleUserAttachment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] project_name: Project Name
        :param pulumi.Input[builtins.str] role_name: Role Name, Valid Values: super_administrator, admin, Custom Role
               
               > **NOTE:** -- super_administrator: the built-in management role of MaxCompute. The Super Administrator of the project has the permission to operate all resources in the project and the management permission. Project owners or users with the Super_Administrator role can assign the Super_Administrator role to other users. -- admin: the built-in management role of MaxCompute, which has the permission to operate all resources in the project and some basic management permissions. Project owners can assign the Admin role to other users. -- Custom role: a role that is not built-in to MaxCompute and needs to be customized. You can refer to the role (starting with role_) definition in DataWorks.
        :param pulumi.Input[builtins.str] user: Supported input: Alibaba Cloud account, RAM user, and RAM role
               
               > **NOTE:** -- Alibaba Cloud account: the account registered on the Alibaba Cloud official website. - RAM User: a user created by an Alibaba Cloud account to assist the Alibaba Cloud account to complete data processing. -- RAM role: a RAM role, like a RAM user, is a type of RAM identity. A RAM role is a virtual user that does not have a specific identity authentication key and needs to be played by a trusted entity user for normal use.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RoleUserAttachmentState.__new__(_RoleUserAttachmentState)

        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["role_name"] = role_name
        __props__.__dict__["user"] = user
        return RoleUserAttachment(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        Project Name
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="roleName")
    def role_name(self) -> pulumi.Output[builtins.str]:
        """
        Role Name, Valid Values: super_administrator, admin, Custom Role

        > **NOTE:** -- super_administrator: the built-in management role of MaxCompute. The Super Administrator of the project has the permission to operate all resources in the project and the management permission. Project owners or users with the Super_Administrator role can assign the Super_Administrator role to other users. -- admin: the built-in management role of MaxCompute, which has the permission to operate all resources in the project and some basic management permissions. Project owners can assign the Admin role to other users. -- Custom role: a role that is not built-in to MaxCompute and needs to be customized. You can refer to the role (starting with role_) definition in DataWorks.
        """
        return pulumi.get(self, "role_name")

    @property
    @pulumi.getter
    def user(self) -> pulumi.Output[builtins.str]:
        """
        Supported input: Alibaba Cloud account, RAM user, and RAM role

        > **NOTE:** -- Alibaba Cloud account: the account registered on the Alibaba Cloud official website. - RAM User: a user created by an Alibaba Cloud account to assist the Alibaba Cloud account to complete data processing. -- RAM role: a RAM role, like a RAM user, is a type of RAM identity. A RAM role is a virtual user that does not have a specific identity authentication key and needs to be played by a trusted entity user for normal use.
        """
        return pulumi.get(self, "user")

